@@ -20,7 +20,6 @@ from Bio.Alphabet import IUPAC
 from Bio.Seq import Seq
 from Bio.SubsMat import FreqTable
 
-__docformat__ = "restructuredtext en"
 
 # Expected random distributions for 20-letter protein, and
 # for 4-letter nucleotide alphabets
@@ -104,8 +103,8 @@ class SummaryInfo(object):
 
             if require_multiple and num_atoms == 1:
                 consensus += ambiguous
-            elif (len(max_atoms) == 1) and ((float(max_size) / float(num_atoms))
-                                            >= threshold):
+            elif (len(max_atoms) == 1) and ((float(max_size) /
+                                             float(num_atoms)) >= threshold):
                 consensus += max_atoms[0]
             else:
                 consensus += ambiguous
@@ -161,8 +160,8 @@ class SummaryInfo(object):
 
             if require_multiple and num_atoms == 1:
                 consensus += ambiguous
-            elif (len(max_atoms) == 1) and ((float(max_size) / float(num_atoms))
-                                            >= threshold):
+            elif (len(max_atoms) == 1) and ((float(max_size) /
+                                             float(num_atoms)) >= threshold):
                 consensus += max_atoms[0]
             else:
                 consensus += ambiguous
@@ -315,9 +314,9 @@ class SummaryInfo(object):
     def _get_all_letters(self):
         """Returns a string containing the expected letters in the alignment."""
         all_letters = self.alignment._alphabet.letters
-        if all_letters is None \
-        or (isinstance(self.alignment._alphabet, Alphabet.Gapped)
-        and all_letters == self.alignment._alphabet.gap_char):
+        if all_letters is None or \
+                (isinstance(self.alignment._alphabet, Alphabet.Gapped) and
+                 all_letters == self.alignment._alphabet.gap_char):
             # We are dealing with a generic alphabet class where the
             # letters are not defined!  We must build a list of the
             # letters used...
@@ -697,55 +696,3 @@ def print_info_content(summary_info, fout=None, rep_record=0):
     for pos in sorted(summary_info.ic_vector):
         fout.write("%d %s %.3f\n" % (pos, rep_sequence[pos],
                    summary_info.ic_vector[pos]))
-
-if __name__ == "__main__":
-    print("Quick test")
-    from Bio import AlignIO
-    from Bio.Align.Generic import Alignment
-
-    filename = "../../Tests/GFF/multi.fna"
-    format = "fasta"
-    expected = FreqTable.FreqTable({"A": 0.25, "G": 0.25, "T": 0.25, "C": 0.25},
-                                   FreqTable.FREQ,
-                                   IUPAC.unambiguous_dna)
-
-    alignment = AlignIO.read(open(filename), format)
-    for record in alignment:
-        print(record.seq)
-    print("=" * alignment.get_alignment_length())
-
-    summary = SummaryInfo(alignment)
-    consensus = summary.dumb_consensus(ambiguous="N")
-    print(consensus)
-    consensus = summary.gap_consensus(ambiguous="N")
-    print(consensus)
-    print("")
-    print(summary.pos_specific_score_matrix(chars_to_ignore=['-'],
-                                            axis_seq=consensus))
-    print("")
-    # Have a generic alphabet, without a declared gap char, so must tell
-    # provide the frequencies and chars to ignore explicitly.
-    print(summary.information_content(e_freq_table=expected,
-                                      chars_to_ignore=['-']))
-    print("")
-    print("Trying a protein sequence with gaps and stops")
-
-    alpha = Alphabet.HasStopCodon(Alphabet.Gapped(Alphabet.generic_protein, "-"), "*")
-    a = Alignment(alpha)
-    a.add_sequence("ID001", "MHQAIFIYQIGYP*LKSGYIQSIRSPEYDNW-")
-    a.add_sequence("ID002", "MH--IFIYQIGYAYLKSGYIQSIRSPEY-NW*")
-    a.add_sequence("ID003", "MHQAIFIYQIGYPYLKSGYIQSIRSPEYDNW*")
-    print(a)
-    print("=" * a.get_alignment_length())
-
-    s = SummaryInfo(a)
-    c = s.dumb_consensus(ambiguous="X")
-    print(c)
-    c = s.gap_consensus(ambiguous="X")
-    print(c)
-    print("")
-    print(s.pos_specific_score_matrix(chars_to_ignore=['-', '*'], axis_seq=c))
-
-    print(s.information_content(chars_to_ignore=['-', '*']))
-
-    print("Done")
